=======
sktools
=======


.. image:: https://img.shields.io/pypi/v/sktools.svg
        :target: https://pypi.python.org/pypi/sktools

.. image:: https://img.shields.io/travis/david26694/sktools.svg
        :target: https://travis-ci.com/david26694/sktools

.. image:: https://readthedocs.org/projects/sktools/badge/?version=latest
        :target: https://sktools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Tools to extend sklearn


* Free software: MIT license
* Documentation: https://sktools.readthedocs.io.


Features
--------

Features include several helpers for sklearn like:

* Selection of columns
* Sparse to dense matrix conversion
* Target encoding-like features
* Quantile featurizers

In addition, there are also methods that are not included in sklearn:

* ``IsEmptyExtractor`` allows to create binary variables indicating if there are missing values.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
